@@ -5,6 +5,7 @@ from uuid import UUID
 
 from tabulate import tabulate
 
+from preseem import NetworkMetadataReference
 from preseem_protobuf.model.element_pb2 import ElementStatus
 
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
@@ -100,6 +101,7 @@ async def sync_preseem_model(preseem_model,
             model_sites[site.uuid] = site
 
         # Create or update elements
+        ap_model_refs = nm_model.refs.get('ap_model') or {}
         for ap_ref in aps.values():
             elem = ap_elem.get(ap_ref.value)
             ip = ap_ref.attributes.get('ip_address')
@@ -119,7 +121,7 @@ async def sync_preseem_model(preseem_model,
                 if updates:
                     logging.info('sync_preseem_model: update element "%s" %s',
                                  UUID(bytes=elem.uuid), updates)
-                    elem = await preseem_model.Element.Update(
+                    await preseem_model.Element.Update(
                         company_uuid=company_uuid, uuid=elem.uuid, **updates)
             else:
                 if ip:
@@ -135,6 +137,14 @@ async def sync_preseem_model(preseem_model,
                     logging.info('sync_preseem_model: created element "%s"',
                                  UUID(bytes=elem.uuid))
                     linked_elems.add(elem.uuid)
+            if elem:
+                model_ref = ap_model_refs.get(ap_ref.value)
+                elem_uuid = str(UUID(bytes=elem.uuid))
+                if not model_ref or model_ref.attributes.get(
+                        'uuid') != elem_uuid:
+                    await nm_model.set_ref(
+                        NetworkMetadataReference('ap_model', ap_ref.value,
+                                                 {'uuid': elem_uuid}))
 
         # Cleanup elements that were referencing a billing entity but are no longer.
         for elem in model_elems.values():
